@@ -9,9 +9,15 @@ PACKAGE_VERSION=$(cat ../../DESCRIPTION \
   | sed 's/[",]//g' \
   | tr -d '[[:space:]]')
 
+DIST_DIR="../../dist/"
+
+if [ ! -d $DIST_DIR ]; then
+  mkdir -p $DIST_DIR;
+fi
+
 PACKAGE_TAR="zonator_$PACKAGE_VERSION.tar.gz"
 
 R CMD build ../../
-mv $PACKAGE_TAR ../../dist
-R CMD check --as-cran ../../dist/$PACKAGE_TAR
+mv $PACKAGE_TAR $DIST_DIR
+R CMD check --as-cran $DIST_DIR$PACKAGE_TAR
 rm -R zonator.Rcheck
